@@ -79,7 +79,8 @@ def fup_or_defup():
         data_limit = limits[product]['limit']
         customer_name = customer['name']
         policy = limits[product]['policy']
-        consumption = core.get_consommation_sum(customer_name)
+        consumption_ko = core.get_consommation_sum(customer_name)
+        consumption = consumption_ko / 1000000000
         fup_status = consumption > data_limit
         core.update_consommation(product, policy, customer_name, fup_status, consumption)
 
