@@ -497,7 +497,7 @@ def get_consommation_sum(customer):
             rows = db.query(sql)
             total = rows.as_dict()
             if total:
-                total = total[0]
+                total = total[0].get('sum', 0)
             else:
                 total = 0
             LOGS.logger.info(
